@@ -87,6 +87,9 @@ int addSession(char* macAddress, char* userId, char* extraId){
   /* write open log to syslog */
   WriteOpenToSyslog(userId, extraId, macAddress);
 
+  /* write log to management db */
+  PutOpenToMngDb(macAddress);
+
   return TRUE;
 }
 
@@ -119,6 +122,9 @@ void delSession(char* macAddress){
   WriteCloseToSyslog(userId, extraId, macAddress, openTime);
   if(debug>0) WriteSessionInfoToSyslog(userId, extraId, 
 				       macAddress, ruleNumber);
+  
+  /* write close log to management db */
+  PutCloseToMngDb(macAddress);
 
   /* reset the memory of MAC IP pair */
   ResetMacIpPairs(macAddress);
@@ -175,6 +181,9 @@ int closeSession(void* pParam, int argc, char *argv[], char* colName[]){
   WriteCloseToSyslog(userId, extraId,  macAddress, openTime);
   if(debug>0) WriteSessionInfoToSyslog(userId, extraId, macAddress, ruleNumber);
 
+  /* write close log to management db */
+  PutCloseToMngDb(macAddress);
+
   /* reset the memory of MAC IP pair */
   ResetMacIpPairs(macAddress);
 
@@ -330,6 +339,7 @@ void removeSessionUnmatchedToIpfwRule(DB* ruleTable, DB* sessionTable){
 	err_msg("ERR at %s#%d: fail to get session info",__FILE__,__LINE__);
       }else{
 	WriteCloseToSyslog(userId, extraId, macAddress, openTime);
+	PutCloseToMngDb(macAddress);
 	DelSessionFromWorkDb(macAddress);
       }
 
@@ -387,6 +397,7 @@ void  removeIpfwRuleUnmatchedToSession(DB* ruleTable, DB* sessionTable){
 
       /* write log */
       WriteCloseToSyslog("?", "", macAddress, time(NULL));
+      PutCloseToMngDb(macAddress);
       
       /* write session info to syslog (no user info)*/
       if(debug>0) WriteSessionInfoToSyslog("?","", macAddress, ruleNumber);
@@ -467,7 +478,7 @@ void setMacIpPair(char* macAddress, char* ipAddress, char* userId, char* extraId
   /* if the pair is not found in work db, record it */
   /* the pair in work db is used for saving session detail (remove at the end of session)*/
   /* one session includes plural pairs (one MAC corresponds to plural IPs) */
-  if(!IsFoundMacIpPairInWorkDb(macAddress, ipAddress)){
+  if(!IsMacIpPairFoundInWorkDb(macAddress, ipAddress)){
     PutMacIpPairToWorkDb(macAddress, ipAddress);
 
     /* write to syslog */
