@@ -462,7 +462,7 @@ int isActiveRuleInWorkDb(int ruleNumber){
 /********************************************
 Is the MAC-IP pair found in work db
 ********************************************/
-int isFoundMacIpPairInWorkDb(char* macAddress, char* ipAddress){
+int isMacIpPairFoundInWorkDb(char* macAddress, char* ipAddress){
   sqlite3_stmt *stmt;
  
   /* SQL SELECT COMMAND, where %x is replaced in snprintf */
@@ -678,12 +678,12 @@ int GetMacInfoFromWorkDb(char* macAddress, char* detectTimeStr, int* pTtl){
   return ret;
 }
 
-int IsFoundMacIpPairInWorkDb(char* macAddress, char* ipAddress){
+int IsMacIpPairFoundInWorkDb(char* macAddress, char* ipAddress){
   int ret;
-  if(debug>1) err_msg("DEBUG:=>isFoundMacIpPairInWorkDb(%s,%s)",
+  if(debug>1) err_msg("DEBUG:=>isMacIpPairFoundInWorkDb(%s,%s)",
 		      macAddress,ipAddress);
-  ret=isFoundMacIpPairInWorkDb(macAddress, ipAddress);
-  if(debug>1) err_msg("DEBUG:(%d)<=isfoundMacIpPairInWorkDb( )", ret);
+  ret=isMacIpPairFoundInWorkDb(macAddress, ipAddress);
+  if(debug>1) err_msg("DEBUG:(%d)<=isMacIpPairFoundInWorkDb( )", ret);
   return ret;
 }
 
